#########################################################################################################
#
# Analysis for the paper/ chapter: computer-based fear regulation during vret social anxiety
# 2018 TUDelft
# This script will generate output: "data_analyses_computer_based_fear_regulation_during_vret_social_anxiety.txt" 
#
# Required datafiles:
# - r_data_calibration.csv
# - r_data_main_session.csv
# - r_ipq_online.sav
# - r_data_questionnaires.csv
# - All system database in the sql_sys folder:
#   consits of: bodyposture_stressor.db, dialogue_stressor.db, eyegaze_stressor.db, hr_dev.db, multimodal_dev.db, multimodal_measure.db,
#               status_flag.db, sud_dev.db
# 
#########################################################################################################

# Adjust this to root folder that contain data files
my_wd <- "D:/Surfdrive/PhD Research/#3/R_chapter_04/"
setwd(my_wd)

# Capture all the output to a file
sink("data_analyses_computer_based_fear_regulation_during_vret_social_anxiety.txt")

# Print R version and operating system version used by this data analyses
sessionInfo()

############################################### LIBRARIES ###############################################
# Libraries used for this analyses 
library(foreign)
library(reshape2)
library(car)
library(ez)
library(psych)
library(dplyr)
library(RSQLite)
#########################################################################################################

################################################ DATA ####################################################

############# Calibration data ################

CalData <- read.csv("r_data_calibration.csv")

# 01. Pid = participants ID number
# 02. age = age of participants
# 03. gender = gender of  participants, coded: male = 0, female = 1
# 04. sud_relax_1 = SUD score in the relax condition at the 1st stage (the 1st 4 minutes measurements)
# 05. sud_relax_2 = SUD score in the relax condition at the 2nd stage (the 2nd 4 minutes measurements)
# 06. sud_relax_3 = SUD score in the relax condition at the 3th stage (the 3th 4 minutes measurements)
# 07. sud_relax_4 = SUD score in the relax condition at the 4th stage (the 4th 4 minutes measurements)
# 08. sud_stress_1 = SUD score in the stress condition at the 1st stage (the 1st 4 minutes measurements)
# 09. sud_stress_2 = SUD score in the stress condition at the 2nd stage (the 2nd 4 minutes measurements)
# 10. sud_stress_3 = SUD score in the stress condition at the 3th stage (the 3th 4 minutes measurements)
# 11. sud_stress_4 = SUD score in the stress condition at the 4th stage (the 4th 4 minutes measurements)
# 12. hr_relax_1 = hr measurements in the relax condition at the 1st stage (the 1st 4 minutes measurements)
# 13. hr_relax_2 = hr measurements in the relax condition at the 2nd stage (the 2nd 4 minutes measurements)
# 14. hr_relax_3 = hr measurements in the relax condition at the 3th stage (the 3th 4 minutes measurements)
# 15. hr_relax_4 = hr measurements in the relax condition at the 4th stage (the 4th 4 minutes measurements)
# 16. hr_stress_1 = hr measurements in the stress condition at the 1st stage (the 1st 4 minutes measurements)
# 17. hr_stress_2 = hr measurements in the stress condition at the 2nd stage (the 2nd 4 minutes measurements)
# 18. hr_stress_3 = hr measurements in the stress condition at the 3th stage (the 3th 4 minutes measurements)
# 19. hr_stress_4 = hr measurements in the stress condition at the 4th stage (the 4th 4 minutes measurements)


############## Main data set of experiment

Maindata <- read.csv("r_data_main_session.csv")

# 01. pid: participants ID number
# 02. iaq_static_1: interview and attitude questionnaires question 1 in the static condition
# 03. iaq_static_2: interview and attitude questionnaires question 2 in the static condition
# 04. iaq_static_3: interview and attitude questionnaires question 3 in the static condition
# 05. iaq_static_4: interview and attitude questionnaires question 4 in the static condition
# 06. iaq_static_5: interview and attitude questionnaires question 5 in the static condition
# 07. iaq_static_6: interview and attitude questionnaires question 6 in the static condition
# 08. iaq_auto_1: interview and attitude questionnaires question 1 in the automatic/ dynamic condition
# 09. iaq_auto_2: interview and attitude questionnaires question 2 in the automatic/ dynamic condition
# 10. iaq_auto_3: interview and attitude questionnaires question 3 in the automatic/ dynamic condition
# 11. iaq_auto_4: interview and attitude questionnaires question 4 in the automatic/ dynamic condition
# 12. iaq_auto_5: interview and attitude questionnaires question 5 in the automatic/ dynamic condition
# 13. iaq_auto_6: interview and attitude questionnaires question 6 in the automatic/ dynamic condition
# 14. sam_static_p_v: SAM questionnaires (Valence dimension) measuring participant's emotion in the static condition
# 15. sam_static_p_a: SAM questionnaires (Arousal dimension) measuring participant's emotion in the static condition
# 16. sam_static_p_d: SAM questionnaires (Dominance dimension) measuring participant's emotion in the static condition
# 17. sam_static_a_v: SAM questionnaires (Valence dimension) measuring avatar's emotion in the static condition
# 18. sam_static_a_a: SAM questionnaires (Arousal dimension) measuring avatar's emotion in the static condition
# 19. sam_static_a_d: SAM questionnaires (Dominance dimension) measuring avatar's emotion in the static condition
# 20. sam_auto_p_v: SAM questionnaires (Valence dimension) measuring participant's emotion in the automatic/ dynamic condition
# 21. sam_auto_p_a: SAM questionnaires (Arousal dimension) measuring participant's emotion in the automatic/ dynamic condition
# 22. sam_auto_p_d: SAM questionnaires (Dominance dimension) measuring participant's emotion in the automatic/ dynamic condition
# 23. sam_auto_a_v: SAM questionnaires (Valence dimension) measuring avatar's emotion in the automatic/ dynamic condition
# 24. sam_auto_a_a: SAM questionnaires (Arousal dimension) measuring avatar's emotion in the automatic/ dynamic condition
# 25. sam_auto_a_d: SAM questionnaires (Dominance dimension) measuring avatar's emotion in the automatic/ dynamic condition
# 26. deq_static: dialogue experience questionnaires questionnares in the static condition
# 27. deq_auto: dialogue experience questionnaires questionnares in the automatic/ dynamic condition
# 28. sias: Social Interaction Anxiety Scale (SIAS) questionnares's result
# 29. ipq_sp1: IPQ question number 1 (sense of being there) in condition 1
# 30. ipq_sp2: IPQ question number 2 (sense of VE surrounds me) in condition 1
# 31. ipq_inv1: IPQ question number 3 (senses of only pictures) in condition 1
# 32. ipq_sp4: IPQ question number 4 (not sense of being in virtual space) in condition 1
# 33. ipq_sp5: IPQ question number 5 (sense of acting in virtual environtment/ VE) in condition 1
# 34. ipq_inv2: IPQ question number 6 (sense of being present in VE) in condition 1
# 35. ipq_inv3: IPQ question number 7 (awareness of real environtment) in condition 1
# 36. ipq_inv4: IPQ question number 8 (not aware of real environtment) in condition 1
# 37. ipq_real4: IPQ question number 9 (no attention to real environtment) in condition 1
# 38. ipq_g1: IPQ question number 10 (attention captivated by VE) in condition 1
# 39. ipq_sp3: IPQ question number 11 (VE real is not real/ real) in condition 1
# 40. ipq_real1: IPQ question number 12 (experience similar to real environtment) in condition 1
# 41. ipq_real2: IPQ question number 13 (VE is imagined/ real) in condition 1
# 42. ipq_real3: IPQ question number 14 (VE seemed more realistic than the real world) in condition 1

##############
IPQdata <- read.spss("r_ipq_online.sav", use.value.labels=TRUE, to.data.frame=TRUE)

# this IPQ data is downloaded from http://igroup.org/pq/ipq/download.php, we took the most relevants items only to be compared with our experiment's results
#
#1.   res         - not used
#2.   study       - not used
#3.   lang        - not used
#4.   version     - not used
#5.   nofcase     - not used
#6.   video       - not used
#7.   audio       - not used
#8.   perspect    - not used
#9.   dura        - not used
#10.  and_r       - not used
#11.  and_s       - not used
#12.  app         - not used
#13.  age         - not used
#14.  gender      - not used
#15.  type        - not used
#16.  g1          - sense of being there - In the computer generated world I had a sense of "being there"
#17.  sp1         - sense of VE behind - Somehow I felt that the virtual world surrounded me.
#18.  sp2         - only pictures - I felt like I was just perceiving pictures.   
#19.  sp3         - not sense of being in v. space - I did not feel present in the virtual space.
#20.  sp4         - sense of acting in VE - I had a sense of acting in the virtual space, rather than operating something from outside.
#21.  sp5         - sense of being present in VE - I felt present in the virtual space.
#22.  inv1        - awareness of real env. - How aware were you of the real world surrounding while navigating in the virtual world? (i.e. sounds, room temperature, other people, etc.)?
#23.  inv2        - not aware of real env. - I was not aware of my real environment.
#24.  inv3        - no attention to real env. - I still paid attention to the real environment.
#25.  inv4        - attention captivated by VE - I was completely captivated by the virtual world.
#26.  real1       - VE real (real/not real) - How real did the virtual world seem to you?
#27.  real2       - experience similar to real env. - How much did your experience in the virtual environment seem consistent with your real world experience ?
#28.  real3       - VE real (imagined/real) - How real did the virtual world seem to you?
#29.  real4       - VE wirklich - The virtual world seemed more realistic than the real world.
#
# Note SP2, INV3, and REAL1 are reversed, eg. (-1 * sp2 + 6)

dataset_questionnaire <- read.csv("r_data_questionnaires.csv")
#
# 01. pid: participants ID number
# 02. iaq_static_1: interview and attitude questionnaires question 1 in the static condition
# 03. iaq_static_2: interview and attitude questionnaires question 2 in the static condition
# 04. iaq_static_3: interview and attitude questionnaires question 3 in the static condition
# 05. iaq_static_4: interview and attitude questionnaires question 4 in the static condition
# 06. iaq_static_5: interview and attitude questionnaires question 5 in the static condition
# 07. iaq_static_6: interview and attitude questionnaires question 6 in the static condition
# 08. iaq_auto_1: interview and attitude questionnaires question 1 in the automatic/ dynamic condition
# 09. iaq_auto_2: interview and attitude questionnaires question 2 in the automatic/ dynamic condition
# 10. iaq_auto_3: interview and attitude questionnaires question 3 in the automatic/ dynamic condition
# 11. iaq_auto_4: interview and attitude questionnaires question 4 in the automatic/ dynamic condition
# 12. iaq_auto_5: interview and attitude questionnaires question 5 in the automatic/ dynamic condition
# 13. iaq_auto_6: interview and attitude questionnaires question 6 in the automatic/ dynamic condition
# 14. sam_static_p_v: SAM questionnaires (Valence dimension) measuring participant's emotion in the static condition
# 15. sam_static_p_a: SAM questionnaires (Arousal dimension) measuring participant's emotion in the static condition
# 16. sam_static_p_d: SAM questionnaires (Dominance dimension) measuring participant's emotion in the static condition
# 17. sam_static_a_v: SAM questionnaires (Valence dimension) measuring avatar's emotion in the static condition
# 18. sam_static_a_a: SAM questionnaires (Arousal dimension) measuring avatar's emotion in the static condition
# 19. sam_static_a_d: SAM questionnaires (Dominance dimension) measuring avatar's emotion in the static condition
# 20. sam_auto_p_v: SAM questionnaires (Valence dimension) measuring participant's emotion in the automatic/ dynamic condition
# 21. sam_auto_p_a: SAM questionnaires (Arousal dimension) measuring participant's emotion in the automatic/ dynamic condition
# 22. sam_auto_p_d: SAM questionnaires (Dominance dimension) measuring participant's emotion in the automatic/ dynamic condition
# 23. sam_auto_a_v: SAM questionnaires (Valence dimension) measuring avatar's emotion in the automatic/ dynamic condition
# 24. sam_auto_a_a: SAM questionnaires (Arousal dimension) measuring avatar's emotion in the automatic/ dynamic condition
# 25. sam_auto_a_d: SAM questionnaires (Dominance dimension) measuring avatar's emotion in the automatic/ dynamic condition
# 26. deq_static: dialogue experience questionnaires questionnares in the static condition
# 27. deq_auto: dialogue experience questionnaires questionnares in the automatic/ dynamic condition
# 28. sias: Social Interaction Anxiety Scale (SIAS) questionnares's result
# 29. ipq_sp1: IPQ question number 1 (sense of being there) in condition 1
# 30. ipq_sp2: IPQ question number 2 (sense of VE surrounds me) in condition 1
# 31. ipq_inv1: IPQ question number 3 (senses of only pictures) in condition 1
# 32. ipq_sp4: IPQ question number 4 (not sense of being in virtual space) in condition 1
# 33. ipq_sp5: IPQ question number 5 (sense of acting in virtual environtment/ VE) in condition 1
# 34. ipq_inv2: IPQ question number 6 (sense of being present in VE) in condition 1
# 35. ipq_inv3: IPQ question number 7 (awareness of real environtment) in condition 1
# 36. ipq_inv4: IPQ question number 8 (not aware of real environtment) in condition 1
# 37. ipq_real4: IPQ question number 9 (no attention to real environtment) in condition 1
# 38. ipq_g1: IPQ question number 10 (attention captivated by VE) in condition 1
# 39. ipq_sp3: IPQ question number 11 (VE real is not real/ real) in condition 1
# 40. ipq_real1: IPQ question number 12 (experience similar to real environtment) in condition 1
# 41. ipq_real2: IPQ question number 13 (VE is imagined/ real) in condition 1
# 42. ipq_real3: IPQ question number 14 (VE seemed more realistic than the real world) in condition 1

# 43. sias_1: SIAS question number 1 (I get nervous if I have to speak with someone in authority)
# 44. sias_2: SIAS question number 1 (I have difficulty making eye contact with others)
# 45. sias_3: SIAS question number 1 (I become tense if I have to talk about myself or my feelings)
# 46. sias_4: SIAS question number 1 ( I find it difficult to mix comfortably with the people I work with)
# 47. sias_5: SIAS question number 1 (I find it easy to make friends my own age)
# 48. sias_6: SIAS question number 1 (I tense up if I meet an acquaintance in the street)
# 49. sias_7: SIAS question number 1 (When mixing socially, I am uncomfortable)
# 50. sias_8: SIAS question number 1 (I feel tense if I am alone with just one other person)
# 51. sias_9: SIAS question number 1 (I am at ease meeting people at parties, etc)
# 52. sias_10: SIAS question number 1 (I have difficulty talking with other people)
# 53. sias_11: SIAS question number 1 (I find it easy to think of things to talk about)
# 54. sias_12: SIAS question number 1 (I worry about expressing myself in case I appear awkward)
# 55. sias_13: SIAS question number 1 (I find it difficult to disagree with another's point of view)
# 56. sias_14: SIAS question number 1 (I have difficulty talking to attractive persons of the opposite sex)
# 57. sias_15: SIAS question number 1 (I find myself worrying that I won't know what to say in social situations)
# 58. sias_16: SIAS question number 1 (I am nervous mixing with people I don't know well)
# 59. sias_17: SIAS question number 1 (I feel I'll say something embarrassing when talking)
# 60. sias_18: SIAS question number 1 (When mixing in a group, I find myself worrying I will be ignored)
# 61. sias_19: SIAS question number 1 (I am tense mixing in a group)
# 62. sias_20: SIAS question number 1 (I am unsure whether to greet someone I know only slightly)
#
# 63. deq_static_1: Dialogue Expereince Questionniare - SPEED (in static condition)
# 64. deq_static_2: Dialogue Expereince Questionniare - INTERACTION (in static condition)
# 65. deq_static_3: Dialogue Expereince Questionniare - CORRECT LOCALLY (in static condition)
# 66. deq_static_4: Dialogue Expereince Questionniare - CORRECT GLOBALLY (in static condition)
# 67. deq_static_5: Dialogue Expereince Questionniare - INVOLVEMENT (in static condition)
# 68. deq_static_6: Dialogue Expereince Questionniare - SATISFACTION (in static condition)
# 69. deq_static_7: Dialogue Expereince Questionniare - REALITY (in static condition)
#
# 70. deq_auto_1: Dialogue Expereince Questionniare - SPEED (in dynamic condition)
# 71. deq_auto_2: Dialogue Expereince Questionniare - INTERACTION (in dynamic condition)
# 72. deq_auto_3: Dialogue Expereince Questionniare - CORRECT LOCALLY (in dynamic condition)
# 73. deq_auto_4: Dialogue Expereince Questionniare - CORRECT GLOBALLY (in dynamic condition)
# 74. deq_auto_5: Dialogue Expereince Questionniare - INVOLVEMENT (in dynamic condition)
# 75. deq_auto_6: Dialogue Expereince Questionniare - SATISFACTION (in dynamic condition)
# 76. deq_auto_7: Dialogue Expereince Questionniare - REALITY (in dynamic condition)


############################################### FUNCTIONS ###############################################
# count gender variable
count_gender <- function(x){
  cat("Female:", length(x[x == "female"]), "Male: ", length(x[x == "male"]))
}

# List available table in the database
db_view_table <- function(database) {
  filename <- database
  sqlite.driver <- dbDriver("SQLite")
  db <- dbConnect(sqlite.driver, dbname = filename)
  ## list table query
  ListTables <- dbListTables(db)
  dbDisconnect(db)
  cat("Your tables: ", ListTables)
}

# Database/ SQL operation
read_db <- function(database, table){
  filename <- database
  sqlite.driver <- dbDriver("SQLite")
  db <- dbConnect(sqlite.driver, dbname = filename)
  ## table query
  dbListTables(db)
  mytable <- dbReadTable(db, table)
  dbDisconnect(db)
  return (mytable)
}

d_effectsizePaired <- function(x1,x2) {
  #calculate Cohen's d effect size, considering it as a one-sample t-test
  # based on Lakens, D. (2013). Calculating and reporting effect sizes to facilitate cumulative science: a practical primer for t-tests and ANOVAs. Frontiers in psychology, 4. https://www.frontiersin.org/articles/10.3389/fpsyg.2013.00863/full
  dif <- x1-x2
  return(mean(dif)/sd(dif))
}

d_effect_alt<- function(x1,x2) {
  d <- 0
  for (i in 1:length(x1)) {d <- d + ((x1[i]-x2[i])-mean(x1-x2))^2}
  return(mean(x1-x2)/((d/23)^0.5))
}

mean_sd <-function(x){
  # print the mean and standard deviation
  cat("Mean: ", mean(x), " sd: ", sd(x), "\n") 

}

pairedttest<-function(x1,x2){
  print( t.test(x1, x2, paired = TRUE))
  cat("Effectsize Cohen's d:",d_effectsizePaired(x1, x2))
}
  
print_ezANOVA <- function(m){
  #print output ezANOVA, including effectsize eta, and Greenhouse-Geisser corrected dfs
  print(m)

  m$ANOVA$eta <- m$ANOVA$SSn/(m$ANOVA$SSn + m$ANOVA$SSd)
  for (i in 1:length(m$ANOVA$Effect)) 
  { cat(m$ANOVA$Effect[i]," : eta ", m$ANOVA$eta[i]," \n")
  }
  cat("see ges-value for Generalized Eta-Squared) \n\n")
  
cat("Greenhouse-Geisser corrected Dfs. \n") 
 for (i in 1:length(m$`Sphericity Corrections`$Effect))
  { 
   for (j in 1:length(m$ANOVA$Effect)) {
    if (m$ANOVA$Effect[j] == m$`Sphericity Corrections`$Effect[i]){
      m$`Sphericity Corrections`$DFn_G[i] <- m$ANOVA$DFn[j] * m$`Sphericity Corrections`$GGe[i]
      m$`Sphericity Corrections`$DFd_G[i] <- m$ANOVA$DFd[j] * m$`Sphericity Corrections`$GGe[i]
      cat(m$`Sphericity Corrections`$Effect[i],
          " numerator ", m$`Sphericity Corrections`$DFn_G[i], " , denominator ", m$`Sphericity Corrections`$DFd_G[i], "\n")

    }
   }
  }
 }


tranformToLong <- function(mshort,idlist, measurelist,measurename)
{ #transform Maindata dataframe for a wide format to long format
  msubset <- subset(mshort, select = c(idlist,measurelist))
  mlong <- melt(msubset, id=idlist, measured = measurelist)
  names(mlong) <- c("participant","SIAS_LowHi","condition8",measurename)
  mlong$SystemRespond <- gl(2, 24*4, length(mlong$participant), c("static","dynamic")) 
  mlong$timeslot <- gl(4, 24, length(mlong$participant), c(1,2,3,4))
  mlong$SIAS_LowHi<-factor(mlong$SIAS_LowHi, levels = c(0:1), labels = c("low","high"))
  return(mlong)
}

pairedttest_sidak<-function(x1,x2,c){
  #paired t test with sidak correction on p-value, c = number of comparisons
  test <- t.test(x1, x2, paired = TRUE)
  test$.psidak <- 1-(1-test$p.value)^c
  print(test)
  cat("p value after Sidak correction:", test$.psidak,"\n" )
  cat("d:",d_effectsizePaired(x1, x2))
}

PostHoc_Stat_vs_Dyn <- function(index,measurename)
{
  #post hoc comparison between static and dynamic condition by time slot
  cat("\n\nMeasure name:", measurename,"\n")
  for (i in 0:3) {
    cat("\n\ntime slot ", 4*i,"-",4*i+4,"\n")
    cat("Static ")
    mean_sd(Maindata[[i+1+index]])
    cat("Dynamic ")
    mean_sd(Maindata[[i+5+index]])
    pairedttest_sidak(Maindata[[i+1+index]],Maindata[[i+5+index]], 4)
  }
}

PostHoc_Dyn_by_slot <- function(index, measurename)
{
  #post hoc comparison dynamic condition compare each slot with first slot
  cat("\n\nMeasure name:", measurename,"\n")
  cat("time slot 0-4 ")
  mean_sd(Maindata[[5+index]])
  for (i in 1:3) {
    cat("\n\ntime slot ", 4*i,"-",4*i+4,"\n")
    mean_sd(Maindata[[i+5+index]])
    pairedttest_sidak(Maindata[[5+index]],Maindata[[i+5+index]], 3)
  }
}

compare_Stat_vs_dynamic <-function(stat,dyn, measurename)  
{ # compare two paired variables 
  cat("\nMeasure :", measurename,"\n")
  cat("Static condition,  ")
  mean_sd(stat)
  cat("Dynamic condition,  ")
  mean_sd(dyn)
  pairedttest(stat,dyn)
}

###########################################################################################################

######################################### ANALYSIS #########################################################
# Participants
cat("Subject analysis\n")
CalData$gender <- factor(CalData$gender, levels = c("m","f"), labels = c("male", "female"))
count_gender(CalData$gender)
cat("\nParticipant age range: ", range(CalData$age))
cat("\nParticipants age M and SD: \n")
mean_sd(CalData$age)

cat("\n\n######## Reliability analysis SIAS, IAQ, and DEQ\n")

cat("Reliability analysis SIAS\n")
sias_alpha <- select(dataset_questionnaire, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52, 53, 54, 55, 56, 57, 58, 59, 60, 61, 62)
x <- alpha(sias_alpha, warnings = FALSE)
cat("Cronbach's alpha of SIAS: ", x$total$raw_alpha)

cat("\nReliability analysis IAQ\n")
iaq_static_alpha <- select(dataset_questionnaire, 2, 3, 4, 5, 6, 7)
x <- alpha(iaq_static_alpha, warnings = FALSE)
alpha_iaq_static <- x$total$raw_alpha

iaq_auto_alpha <- select(dataset_questionnaire, 8, 9, 10, 11, 12, 13)
x <- alpha(iaq_auto_alpha, warnings = FALSE)
alpha_iaq_auto <- x$total$raw_alpha
cat("Cronbach's alpha of IAQ : ", (alpha_iaq_static + alpha_iaq_auto)/2)

cat("\nReliability analysis DEQ\n")
deq_static_alpha <- select(dataset_questionnaire, 63, 64, 65, 66, 67, 68, 69)
x <- alpha(deq_static_alpha, warnings = FALSE)
alpha_deq_static <- x$total$raw_alpha

deq_auto_alpha <- select(dataset_questionnaire, 70, 71, 72, 73, 74, 75, 76)
x <- alpha(deq_auto_alpha, warnings = FALSE)
alpha_deq_auto <- x$total$raw_alpha
cat("Cronbach's alpha of DEQ : ", (alpha_deq_static + alpha_deq_auto)/2)

cat("\n\nSIAS - ")
mean_sd(dataset_questionnaire$sias)

# DATABASE OPERATION Directory
db_op <- paste(my_wd, "sql_sys/", sep = "") 
setwd(db_op)

# System status flag
#db_view_table("status_flag.db")
status_flag <- read_db("status_flag.db", "status_flag")
cat("Ideal calibartion rule: ", nrow(status_flag[status_flag$status_flag == 1,]), "participants\n") 
cat("SUD calibartion rule: ", nrow(status_flag[status_flag$status_flag == 2,]), "participants\n") 
cat("HR calibartion rule: ", nrow(status_flag[status_flag$status_flag == 3,]), "participants\n") 

Maindata$SIAS_LowHi_check[dataset_questionnaire$sias < mean(dataset_questionnaire$sias)] <- 0
Maindata$SIAS_LowHi_check[dataset_questionnaire$sias > mean(dataset_questionnaire$sias)] <- 1

if (sd(Maindata$SIAS_LowHi_check-Maindata$SIAS_LowHi)==0) {
  cat("No deviation found between Variable SIAS LowHi in DataMain file and calculated variable based on SIAS mean\n")
  } else {
    cat("Deviation found between Variable SIAS LowHi in DataMain file and calculated variable based on SIAS mean\n")
    }

cat("\n...in the dynamic condition it remained relatively stable (M, SD): \n")
multimodal_dynamic <- read_db("multimodal_measure.db", "dynamic")
mean_sd((multimodal_dynamic$stage_1 + multimodal_dynamic$stage_2 + multimodal_dynamic$stage_3 + multimodal_dynamic$stage_4)/4)

cat("\nOn average it deviated M(SD) from the reference value.\n")
multimodal_dev_dynamic <- read_db("multimodal_dev.db", "dynamic")
mean_sd((multimodal_dev_dynamic$stage_1 + multimodal_dev_dynamic$stage_2 + multimodal_dev_dynamic$stage_3 + multimodal_dev_dynamic$stage_4)/4)

# system status flag:
# Group status:
# 1: ideal rule, 2: SUD rule, 3: HR rule
multimodal_dev_dynamic$status_flag[status_flag$status_flag == 1] <- 1
multimodal_dev_dynamic$status_flag[status_flag$status_flag == 2] <- 2
multimodal_dev_dynamic$status_flag[status_flag$status_flag == 3] <- 3

cat("A Similiar pattern was observed for the 2 participants that used the SUD score calibration rule M(SD): (look at group = 2)\n")
cat("and 2 that used the heart rate only calibration rule M(SD): (look at group = 3)\n")
multimodal_dev_dynamic$overall <- (multimodal_dev_dynamic$stage_1 + multimodal_dev_dynamic$stage_2 + multimodal_dev_dynamic$stage_3 + multimodal_dev_dynamic$stage_4)/4
describeBy(multimodal_dev_dynamic$overall, multimodal_dev_dynamic$status_flag)


cat("\n######## Table 4.1 - Comparison between relaxing and anxious condition during calibration phase\n")

cat("## Relax condition M and SD\n")
cat("# SUD score\n")
for (i in 4:7) {mean_sd(CalData[[i]])}

cat("\n#Heart rate\n")
for (i in 12:15) {mean_sd(CalData[[i]])}


cat("## Anxious condition condition M and SD\n")
cat("# SUD score\n")
for (i in 8:11) {mean_sd(CalData[[i]])}

cat("#Heart rate\n")
for (i in 16:19) {mean_sd(CalData[[i]])}


cat("\n### Comparing measurement in relaxed and anxious condition in same measuring time slot\n")

cat("## SUD\n")
cat("# time slot 0-1 to 3-4 minutes\n")
for (i in 4:7) {pairedttest(CalData[[i]],CalData[[i+4]])}


cat("\n## Heart rate\n")
cat("# time slot 0-1 minutes\n")
for (i in 12:15) {pairedttest(CalData[[i]],CalData[[i+4]])}


cat("\n\n######## Table 4.2 - Mean (SD) of the outcome measures: Multimodual anxiety scale, SUD score rating, heart rate, heart rate variability and length of speak; and the stressors: Dialogue, Eye Gaze, and Body Posture in Static and Dynamic condition\n")

cat("\n\n### Multimodal anxiety (0%-100%) Mean and Sd\n")
## Measurment*
## Static condition
# Overall
cat("Measurement - Overall Static condition (in precentages %)\n")
multimodal_static <- read_db("multimodal_measure.db", "static")
mean_sd((multimodal_static$stage_1 + multimodal_static$stage_2 + multimodal_static$stage_3 + multimodal_static$stage_4)/4)

#Time slot 0-4 to 12-16
cat("Measurement - Time slot 0-4 to 12-16, Static condition (in precentages %)\n")
for (i in 2:5) {mean_sd(multimodal_static[[i]])}

## Dynamic condition
# Overall
cat("Measurement - Overall Dynamic condition (in precentages %)\n")
multimodal_dynamic <- read_db("multimodal_measure.db", "dynamic")
mean_sd((multimodal_dynamic$stage_1 + multimodal_dynamic$stage_2 + multimodal_dynamic$stage_3 + multimodal_dynamic$stage_4)/4)

#Time slot 0-4 to 12-16
cat("Measurement - Time slot 0-4 to 12-16, Dynamic condition (in precentages %)\n")
for (i in 2:5) {mean_sd(multimodal_dynamic[[i]])}

## Deviation**
## Static condition
# Overall
cat("Deviation - Overall Static condition (in precentages %)\n")
multimodal_dev_static <- read_db("multimodal_dev.db", "static")
mean_sd((multimodal_dev_static$stage_1 + multimodal_dev_static$stage_2 + multimodal_dev_static$stage_3 + multimodal_dev_static$stage_4)/4)

#Time slot 0-4 to 12-16
cat("Deviation - Time slot 0-4 to 12-16, Static condition (in precentages %)\n")
for (i in 2:5) {mean_sd(multimodal_dev_static[[i]])}

## Dynamic condition
# Overall
cat("Deviation - Overall Dynamic condition (in precentages %)\n")
multimodal_dev_dynamic <- read_db("multimodal_dev.db", "dynamic")
mean_sd((multimodal_dev_dynamic$stage_1 + multimodal_dev_dynamic$stage_2 + multimodal_dev_dynamic$stage_3 + multimodal_dev_dynamic$stage_4)/4)

#Time slot 0-4 to 12-16
cat("Deviation - Time slot 0-4 to 12-16, Dynamic condition (in precentages %)\n")
for (i in 2:5) {mean_sd(multimodal_dev_dynamic[[i]])}


cat("\n### SUD score (0-10) Mean and SD\n")
cat("## Static condition\n")
cat("# Overall\n")
mean_sd((Maindata$sud_static_1 + Maindata$sud_static_2 + Maindata$sud_static_3 + Maindata$sud_static_4)/4)

cat("#Time slot 0-4 to 12-16\n")
for (i in 2:5) {mean_sd(Maindata[[i]])}

cat("## Dynamic condition\n")
cat("# Overall\n")
mean_sd((Maindata$sud_auto_1 + Maindata$sud_auto_2 + Maindata$sud_auto_3 + Maindata$sud_auto_4)/4)

cat("#Time slot 0-4 to 12-16\n")
for (i in 6:9) {mean_sd(Maindata[[i]])}

cat("# SUD deviation (in precentages %)\n")
## Deviation**
cat("Overall - Static condition\n")
sud_dev_static <- read_db("sud_dev.db", "static")
mean_sd((sud_dev_static$stage_1 + sud_dev_static$stage_2 + sud_dev_static$stage_3 + sud_dev_static$stage_4)/4)

#Time slot 0-4 to 12-16
cat("Time slot 0-4 to 12-16\n")
for (i in 2:5) {mean_sd(sud_dev_static[[i]])}

## Dynamic condition
# Overall
cat("Overall - Dynamic condition\n")
sud_dev_dynamic <- read_db("sud_dev.db", "dynamic")
mean_sd((sud_dev_dynamic$stage_1 + sud_dev_dynamic$stage_2 + sud_dev_dynamic$stage_3 + sud_dev_dynamic$stage_4)/4)

#Time slot 0-4 to 12-16
cat("Time slot 0-4 to 12-16")
for (i in 2:5) {mean_sd(sud_dev_dynamic[[i]])}

cat("### Hart rate (bpm unit) Mean and SD\n")
cat("## Static condition\n")
cat("# Overall\n")
mean_sd((Maindata$hr_static_1 + Maindata$hr_static_2 + Maindata$hr_static_3 + Maindata$hr_static_4)/4)

cat("#Time slot 0-4 to 12-16\n")
for (i in 10:13) {mean_sd(Maindata[[i]])}

cat("## Dynamic condition\n")
cat("# Overall\n")
mean_sd((Maindata$hr_auto_1 + Maindata$hr_auto_2 + Maindata$hr_auto_3 + Maindata$hr_auto_4)/4)

cat("#Time slot 0-4 to 12-16\n")
for (i in 14:17) {mean_sd(Maindata[[i]])}

cat("# HR deviation (in precentages %)\n")
## Deviation**
## Static condition
cat("Overall - Static condition\n")
hr_dev_static <- read_db("hr_dev.db", "static")
mean_sd((hr_dev_static$stage_1 + hr_dev_static$stage_2 + hr_dev_static$stage_3 + hr_dev_static$stage_4)/4)

#Time slot 0-4 to 12-16
cat("Time slot 0-4 to 12-16\n")
for (i in 2:5) {mean_sd(hr_dev_static[[i]])}

## Dynamic condition
cat("Overall - Dynamic condition\n")
hr_dev_dynamic <- read_db("hr_dev.db", "dynamic")
mean_sd((hr_dev_dynamic$stage_1 + hr_dev_dynamic$stage_2 + hr_dev_dynamic$stage_3 + hr_dev_dynamic$stage_4)/4)

#Time slot 0-4 to 12-16
cat("Time slot 0-4 to 12-16\n")
for (i in 2:5) {mean_sd(hr_dev_dynamic[[i]])}

cat("### RMSSD (s) Mean and SD\n")
cat("## Static condition\n")
cat("# Overall\n")
mean_sd((Maindata$hrv_static_1 + Maindata$hrv_static_2 + Maindata$hrv_static_3 + Maindata$hrv_static_3)/4)

cat("#Time slot 0-4 to 12-16\n")
for (i in 26:29) {mean_sd(Maindata[[i]])}

cat("## Dynamic condition\n")
cat("# Overall\n")
mean_sd((Maindata$hrv_auto_1 + Maindata$hrv_auto_2 + Maindata$hrv_auto_3 + Maindata$hrv_auto_4)/4)

cat("#Time slot 0-4 to 12-16\n")
for (i in 30:33) {mean_sd(Maindata[[i]])}


cat("### Length of speak (s) Mean and SD\n")
cat("## Static condition\n")
cat("# Overall\n")
mean_sd((Maindata$speak_static_1 + Maindata$speak_static_2 + Maindata$speak_static_3 + Maindata$speak_static_4)/4)

cat("#Time slot 0-4 to 12-16\n")
for (i in 18:21) {mean_sd(Maindata[[i]])}

cat("## Dynamic condition\n")
cat("# Overall\n")
mean_sd((Maindata$speak_auto_1 + Maindata$speak_auto_2 + Maindata$speak_auto_3 + Maindata$speak_auto_4)/4)

cat("#Time slot 0-4 to 12-16\n")
for (i in 22:25) {mean_sd(Maindata[[i]])}

cat("#Stressors (0% - 100%)\n\n")

cat("Dialogue - Static condition\n")
cat("Time slot 0-4 to 12-16\n")
dialogue_static <- read_db("dialogue_stressor.db", "static")
for (i in 2:5) {mean_sd(dialogue_static[[i]])}

cat("Dialogue - Dynamic condition\n")
cat("Time slot 0-4 to 12-16\n")
dialogue_dynamic <- read_db("dialogue_stressor.db", "dynamic")
for (i in 2:5) {mean_sd(dialogue_dynamic[[i]])}

cat("Eye gaze - Static condition\n")
cat("Time slot 0-4 to 12-16\n")
gaze_static <- read_db("eyegaze_stressor.db", "static")
for (i in 2:5) {mean_sd(gaze_static[[i]])}

cat("Eye gaze - Dynamic condition\n")
cat("Time slot 0-4 to 12-16\n")
gaze_dynamic <- read_db("eyegaze_stressor.db", "dynamic")
for (i in 2:5) {mean_sd(gaze_dynamic[[i]])}

cat("Body posture - Static condition\n")
cat("Time slot 0-4 to 12-16\n")
posture_static <- read_db("bodyposture_stressor.db", "static")
for (i in 2:5) {mean_sd(posture_static[[i]])}

cat("Body posture - Dynamic condition\n")
cat("Time slot 0-4 to 12-16\n")
posture_dynamic <- read_db("bodyposture_stressor.db", "dynamic")
for (i in 2:5) {mean_sd(posture_dynamic[[i]])}


cat("\n######## Table 4.3 - Multi- and Univariate Analyses with Both Static and Dynamic System Responses as Within-Subject Factor and Social Anxiety Group as Between-SUbject Factor on SUD Score Rating, Heart Rate, Heart Rate Variability and Length of Speak\n")
for (i in 1:length(Maindata$sud_static_1)) {Maindata$participant[[i]] <- i}
#convert participants into factor
Maindata$participant <- factor(Maindata$participant)

cat("\n## for result of Doubly MANOVA repeated-measure analyses see SPSS output\n")

cat("\n## SUD score\n")
MaindatalongSUD <-tranformToLong(Maindata,c("participant","SIAS_LowHi_check"), c("sud_static_1", "sud_static_2", "sud_static_3", "sud_static_4", "sud_auto_1", "sud_auto_2", "sud_auto_3","sud_auto_4"), "SUD")
Sudmodel <- ezANOVA(data = MaindatalongSUD, dv = .(SUD), wid = .(participant), within = .(SystemRespond, timeslot), between = .(SIAS_LowHi), detailed = TRUE, type =3)
print_ezANOVA(Sudmodel)

cat("\n## Heart rate (bpm)\n")
MaindatalongHR <-tranformToLong(Maindata,c("participant","SIAS_LowHi_check"), c("hr_static_1", "hr_static_2", "hr_static_3", "hr_static_4", "hr_auto_1", "hr_auto_2", "hr_auto_3","hr_auto_4"), "HR")
HRmodel <- ezANOVA(data = MaindatalongHR, dv = .(HR), wid = .(participant), within = .(SystemRespond, timeslot), between = .(SIAS_LowHi), detailed = TRUE, type =3)
print_ezANOVA(HRmodel)

cat("\n## Heart rate variability\n") 
MaindatalongRMSSD <-tranformToLong(Maindata,c("participant","SIAS_LowHi_check"), c("hrv_static_1", "hrv_static_2", "hrv_static_3", "hrv_static_4", "hrv_auto_1", "hrv_auto_2", "hrv_auto_3","hrv_auto_4"), "RMSSD")
RMSSDmodel <- ezANOVA(data = MaindatalongRMSSD, dv = .(RMSSD), wid = .(participant), within = .(SystemRespond, timeslot), between = .(SIAS_LowHi), detailed = TRUE, type =3)
print_ezANOVA(RMSSDmodel)

cat("\n##Length of speak\n")
MaindatalongSpeak <-tranformToLong(Maindata,c("participant","SIAS_LowHi_check"), c("speak_static_1", "speak_static_2", "speak_static_3", "speak_static_4", "speak_auto_1", "speak_auto_2", "speak_auto_3","speak_auto_4"), "Speak")
Speakmodel <- ezANOVA(data = MaindatalongSpeak, dv = .(Speak), wid = .(participant), within = .(SystemRespond, timeslot), between = .(SIAS_LowHi), detailed = TRUE, type =3)
print_ezANOVA(Speakmodel)


cat("\n\n######## Table 4.4 - Comparison Between Static and Dynamic System Response for the Different Measuring Time-Slot\n")

PostHoc_Stat_vs_Dyn(1, "SUD")
PostHoc_Stat_vs_Dyn(9, "Heart rate")
PostHoc_Stat_vs_Dyn(25, "Heart rate variability")
PostHoc_Stat_vs_Dyn(17, "Audio Length")

cat("\n\n######## Table 4.5 - Comparison Between First Time-Slot and Second, Third and Fourth Time-Slot in Dynamic Condition\n")
PostHoc_Dyn_by_slot(1, "SUD")
PostHoc_Dyn_by_slot(9, "Heart rate")
PostHoc_Dyn_by_slot(25, "Heart rate variability")
PostHoc_Dyn_by_slot(17, "Audio Length")


cat("\n\n######## Table 4.6 - Mean and SD of the Process Measures record in Static and Dynamic Condition\n")

compare_Stat_vs_dynamic(dataset_questionnaire$deq_static, dataset_questionnaire$deq_auto, "Total DEQ")
compare_Stat_vs_dynamic(rowSums(dataset_questionnaire[2:7]), rowSums(dataset_questionnaire[8:13]), "Total IAQ")
cat("SAM - Participant\n")
compare_Stat_vs_dynamic(dataset_questionnaire$sam_static_p_v, dataset_questionnaire$sam_auto_p_v, "SAM-Valence Participant")
compare_Stat_vs_dynamic(dataset_questionnaire$sam_static_p_a, dataset_questionnaire$sam_auto_p_a, "SAM-Arousal Participant")
compare_Stat_vs_dynamic(dataset_questionnaire$sam_static_p_d, dataset_questionnaire$sam_auto_p_d, "SAM-Dominance Participant")
cat("SAM - Avatar\n")
compare_Stat_vs_dynamic(dataset_questionnaire$sam_static_a_v, dataset_questionnaire$sam_auto_a_v, "SAM-Valence Avatar")
compare_Stat_vs_dynamic(dataset_questionnaire$sam_static_a_a, dataset_questionnaire$sam_auto_a_a, "SAM-Arousal Avatar")
compare_Stat_vs_dynamic(dataset_questionnaire$sam_static_a_d, dataset_questionnaire$sam_auto_a_d, "SAM-Dominance Avatar")

cat("\n\n######## IPQ analysis\n")
cat("Mean and SD IPQ experiment: \n")
dataset_questionnaire$ipq_exp_total <- rowSums(dataset_questionnaire[29:42])
mean_sd(dataset_questionnaire$ipq_exp_total)

cat("Mean and SD IPQ online: \n")
IPQdata$total_online_ipq <- (rowMeans(IPQdata[16:29], na.rm = TRUE)) * (ncol(IPQdata) - 15)
mean_sd(IPQdata$total_online_ipq)

cat("T-test between IPQ experiment and IPQ online dataset: \n")
# Taken From https://stats.stackexchange.com/questions/15722/how-to-use-levene-test-function-in-r#15723
# General code to reshape two vectors into a long data.frame
twoVarWideToLong <- function(sample1,sample2) {
  res <- data.frame(
    GroupID=as.factor(c(rep(1, length(sample1)), rep(2, length(sample2)))),
    DV=c(sample1, sample2)
  )   
}   

# (Step 1) Reshaping the example data
long.data <- twoVarWideToLong(dataset_questionnaire$ipq_exp_total, IPQdata$total_online_ipq)

# (Step 2) As Levenetest is sign, homogeneity of variance should not be assumpted
leveneTest(DV~GroupID,long.data)

# (step 3)
t.test(dataset_questionnaire$ipq_exp_total, IPQdata$total_online_ipq, paired = FALSE, var.equal = FALSE, alternative = "t")


#add SIAS group into experiment IPQ
dataset_questionnaire$SIAS_LowHi_check[dataset_questionnaire$sias < mean(dataset_questionnaire$sias)] <- 0
dataset_questionnaire$SIAS_LowHi_check[dataset_questionnaire$sias > mean(dataset_questionnaire$sias)] <- 1

cat("\n# Compare IPQTotal of two SIAS group\n")
dataset_questionnaire$SIAS_LowHi_check <- factor(dataset_questionnaire$SIAS_LowHi_check)
leveneTest(ipq_exp_total ~ SIAS_LowHi_check, data=dataset_questionnaire)
# As Levenetest is not sign, homogeneity of variance could be assumpted
t.test(dataset_questionnaire$ipq_exp_total ~ dataset_questionnaire$SIAS_LowHi_check, paired = FALSE, var.equal = TRUE, alternative = "t")


## stop redireting output.
sink()

cat("\n\nOutput of this R script file: data_analyses_computer_based_fear_regulation_during_vret_social_anxiety.txt") 

